@@ -1,4 +1,5 @@
 CREATE TABLE func_import_hub_update(
+    update_uuid VARCHAR(40) NOT NULL,
     hub_uuid VARCHAR(40) NOT NULL,
     related_update_uuid VARCHAR(40),
     default_location_uuid VARCHAR(40)
@@ -12,7 +13,7 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        'TRIGGER bi_func_import_hub_update_1',
+        NEW.update_uuid,
         NEW.hub_uuid,
         NEW.related_update_uuid,
         NEW.default_location_uuid
@@ -26,12 +27,16 @@ BEGIN
             default_location_id
         )
     SELECT
-        currval('updates'),
+        u.id,
         hubs.id,
         NEW.related_update_uuid,
         hl.id
     FROM
         topics AS hubs
+    INNER JOIN
+        updates u
+    ON
+        u.uuid = NEW.update_uuid
     LEFT JOIN
         topics hl
     ON
