@@ -1,4 +1,5 @@
 CREATE TABLE func_import_project_status(
+    update_uuid VARCHAR(40) NOT NULL,
     project_uuid VARCHAR(40) NOT NULL,
     status VARCHAR(40) NOT NULL,
     rank INTEGER NOT NULL
@@ -13,7 +14,7 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        'TRIGGER bi_func_import_project_status_1',
+        NEW.update_uuid,
         NEW.project_uuid,
         NEW.status,
         NEW.rank
@@ -21,16 +22,22 @@ BEGIN
 
     INSERT INTO
         func_new_project_status(
+            update_id,
             project_id,
             status,
             rank
         )
     SELECT
+        u.id,
         projects.id,
         NEW.status,
         NEW.rank
     FROM
         topics AS projects
+    INNER JOIN
+        updates u
+    ON
+        u.uuid = NEW.update_uuid
     WHERE
         projects.uuid = NEW.project_uuid
     ;
